# Covmatic RobotControl

## v0.0.6

- [RobotStation] Added *RobotManager* server **port** parameter.

## v0.0.5

- Advanced *covmatic-stations* requirements to v2.19.7

## v0.0.4

- Added home command from *covmatic-stations* v2.19.6

## v0.0.3

- Renamed project to **covmatic-robotstation**
- [Robot API] Fixed action request

## v0.0.2

Initial release

